@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-__version__ = "0.0.5"
+__version__ = "0.0.6"
 __desc__ = "Automate process of downloading name your price albums from bandcamp."
 
 import argparse
@@ -15,6 +15,7 @@ import requests
 from selenium import webdriver
 from selenium.common.exceptions import *
 from selenium.webdriver.common.by import By
+from selenium.webdriver.firefox.firefox_profile import FirefoxProfile
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.ui import Select, WebDriverWait
 
@@ -58,6 +59,8 @@ def main():
     parser.add_argument(
         "--encoding",
         "-e",
+        "--format",
+        "-f",
         type=str,
         choices=("mp3", "mp3v0", "flac", "aac", "ogg", "alac", "wav", "aiff"),
         help="desired encoding",
@@ -133,6 +136,13 @@ def main():
     album_url = args.album_url
     download_url = None
     local_file_name = None
+    driver = None
+
+    def finish_and_exit(code):
+        if driver:
+            driver.close()
+            driver.quit()
+        exit(code)
 
     # Load cache
     if not args.ignore_cache:
@@ -190,7 +200,7 @@ def main():
         loaded_cache.append({"album_url": album_url})
         cache_entry = loaded_cache[-1]
 
-    if download_url is None:
+    if download_url is None or requests.head(download_url).status_code != 200:
         if args.encoding is not None:
             if args.encoding == "mp3":
                 onsite_encoding = "MP3 320"
@@ -206,18 +216,20 @@ def main():
         if args.driver is None:
             args.driver = "chromium"
         if args.driver in ("chrome", "chromium"):
+            options = webdriver.ChromeOptions()
             if not args.show_browser_window:
-                options = webdriver.ChromeOptions()
                 options.add_argument("--headless")
-            else:
-                options = None
+                options.add_argument("--disable-gpu")
+            options.add_argument("--blink-settings=imagesEnabled=false")
             driver = webdriver.Chrome(options=options)
         elif args.driver == "edge":
             driver = webdriver.Edge()
         elif args.driver in ("firefox", "gecko"):
+            profile = FirefoxProfile()
+            profile.set_preference("permissions.default.image", 2)
             if not args.show_browser_window:
                 os.environ["MOZ_HEADLESS"] = "1"
-            driver = webdriver.Firefox()
+            driver = webdriver.Firefox(profile)
         elif args.driver == "opera":
             driver = webdriver.Opera()
         elif args.driver == "phantomjs":
@@ -227,10 +239,6 @@ def main():
         elif args.driver == "webkit":
             driver = webdriver.WebKitGTK()
 
-        def finish_and_exit(code):
-            driver.quit()
-            exit(code)
-
         check_if_album_is_name_your_price = not args.skip_nyp_check
         page_load_wait_time = args.wait_time
         preparing_wait_time = args.preparing_wait_time
@@ -355,8 +363,7 @@ def main():
             encoding_dropdown_button.click()
 
             format_list_element = driver.find_element_by_xpath(
-                f"//*[@id='post-checkout-info']/div[1]/div[2]/div[4]/div[4]/ul"
-                "//*[text()='{onsite_encoding}']"
+                f"//*[@id='post-checkout-info']/div[1]/div[2]/div[4]/div[4]/ul//*[text()='{onsite_encoding}']"
             )
             format_list_element.click()
 
@@ -368,7 +375,7 @@ def main():
 
         download_url = direct_download_link.get_attribute("href")
     else:
-        eprint("Download url exists in cache. Skipping scrapping.")
+        eprint("Active download url exists in cache. Skipping scrapping.")
 
     if args.print_url:
         print(download_url)
